function wlCommonInit(){
	/*
	 * Use of WL.Client.connect() API before any connectivity to a Worklight Server is required. 
	 * This API should be called only once, before any other WL.Client methods that communicate with the Worklight Server.
	 * Don't forget to specify and implement onSuccess and onFailure callback functions for WL.Client.connect(), e.g:
	 *    
	 *    WL.Client.connect({
	 *    		onSuccess: onConnectSuccess,
	 *    		onFailure: onConnectFailure
	 *    });
	 *     
	 */
	
	// Common initialization code goes here
	busyIndicator = new WL.BusyIndicator();	
	$("#collapsible-set").empty();
	// connect to z/VSE and get information during app loading
	getInfo();
	
}

function addNewCar(){
	busyIndicator.show();

	var manufacture = document.getElementById('textManufacture').value;
	var type 		= document.getElementById('textType').value;
	var model 		= document.getElementById('textModel').value;
	var hp 			= document.getElementById('textHP').value;
	var displacement = document.getElementById('textDisplacement').value;
	var cylinders 	= document.getElementById('textCylinders').value;
	var colour 		= document.getElementById('textColour').value;
	var features 	= document.getElementById('textFeatures').value;
	var price 		= document.getElementById('textPrice').value;
	
	//hide "add new car" panel
	$("#collapsiblePanel").collapsible({ collapsed: true });
	
	var invocationData = {  // call adapter with predefined procedure
			adapter : 'connectorsAdapter',
			procedure : 'addNewCar',
			parameters : [manufacture, type, model, hp, displacement, cylinders, colour, features, price]
		};
	
	WL.Client.invokeProcedure(invocationData,{  // show result
		onSuccess : showResultSuccess,
		onFailure : showResultFailure
	});

}

function getInfo( ){
	
	busyIndicator.show();
	
	var invocationData = {  // call adapter with predefined procedure
			adapter : 'connectorsAdapter',
			procedure : 'getInfo',
			parameters : []
		};

	WL.Client.invokeProcedure(invocationData,{  // show result
		onSuccess : showResultSuccess,
		onFailure : showResultFailure
	});
	
}



function changeCar(i){
	busyIndicator.show();

	var manufacture = document.getElementById('textManufacture'+i).value;
	var type 		= document.getElementById('textType'+i).value;
	var model 		= document.getElementById('textModel'+i).value;
	var hp 			= document.getElementById('textHP'+i).value;
	var displacement = document.getElementById('textDisplacement'+i).value;
	var cylinders 	= document.getElementById('textCylinders'+i).value;
	var colour 		= document.getElementById('textColour'+i).value;
	var features 	= document.getElementById('textFeatures'+i).value;
	var price 		= document.getElementById('textPrice'+i).value;
	
	var invocationData = {  // call adapter with predefined procedure
			adapter : 'connectorsAdapter',
			procedure : 'changeCar',
			parameters : [i, manufacture, type, model, hp, displacement, cylinders, colour, features, price]
		};
	
	WL.Client.invokeProcedure(invocationData,{  // show result
		onSuccess : showResultSuccess,
		onFailure : showResultFailure
	});
}

function deleteCar(i){
	//alert(i);
	busyIndicator.show();

	var invocationData = {  // call adapter with predefined procedure
			adapter : 'connectorsAdapter',
			procedure : 'deleteCar',
			parameters : [i]
		};
	
	WL.Client.invokeProcedure(invocationData,{  // show result
		onSuccess : showResultSuccess,
		onFailure : showResultFailure
	});
}

function displayFeeds(feeds){
	
	
	$("#collapsible-set").empty();
	
	var ul = $("#collapsible-set");
	
	var liText15 = "</div>";
	var labelFor = "<label for=\"text\">";
	var inputType = "</label><input type=\"text\" name=\"text\" id=";
	
	
    for (var i = 0; i < feeds.length; i++) {
    	var dataItem = feeds[i];
		// ARTICLENO 	MANUFACTURER 	TYPE 	MODEL 	HP 	DISPLACEMENT 	CYLINDERS 	COLOUR 	FEATURES 	PRICE

    	var liText = "<div data-role=\"collapsible\" id=\"collapsible" + i + "\">";
    	liText += "<h3>" + dataItem.MANUFACTURER + ": " + dataItem.TYPE + "</h3>";
    	liText += labelFor + "Manufacture:" + inputType + "\"textManufacture" 	+ i + "\" value=\"" + dataItem.MANUFACTURER	+"\">";
    	liText += labelFor + "Type:" 		+ inputType + "\"textType" 			+ i + "\" value=\"" + dataItem.TYPE			+"\">";
    	liText += labelFor + "Model:" 		+ inputType + "\"textModel" 		+ i + "\" value=\"" + dataItem.MODEL		+"\">";
    	liText += labelFor + "HP:" 			+ inputType + "\"textHP" 			+ i + "\" value=\"" + dataItem.HP			+"\">";
    	liText += labelFor + "Displacement:" + inputType +"\"textDisplacement" 	+ i + "\" value=\"" + dataItem.DISPLACEMENT	+"\">";
    	liText += labelFor + "Cylinders:" 	+ inputType + "\"textCylinders" 	+ i + "\" value=\"" + dataItem.CYLINDERS	+"\">";
    	liText += labelFor + "Colour:" 		+ inputType + "\"textColour" 		+ i + "\" value=\"" + dataItem.COLOUR		+"\">";
    	liText += labelFor + "Features:" 	+ inputType + "\"textFeatures" 		+ i + "\" value=\"" + dataItem.FEATURES		+"\">";
    	liText += labelFor + "Price:" 		+ inputType + "\"textPrice" 		+ i + "\" value=\"" + dataItem.PRICE		+"\">";

    	
    	liText += "<div data-role=\"controlgroup" + i + "\" data-type=\"horizontal\">";
    	liText += "<form><input type=\"button\" name=\"buttonChange" + i + "\" value=\"Modify\" onclick=\"changeCar(" + i + ")\">"; 
    	liText += "<input type=\"button\" name=\"buttonDelete" + i + "\" value=\"Delete\" onclick=\"deleteCar(" + i + ")\"></form>";
    	liText += "</div>";
    	
    	var listItem = $(liText + liText15);
        ul.append(listItem);
    }
    
    for (var i = 0; i < feeds.length; i++) {
        var p = "#collapsible"+i;
    	$(p).collapsible({ collapsed: true });
    	$(p).collapsible({ collapsedIcon: "arrow-r" });
    	$(p).collapsible({ expandedIcon: "arrow-d"	});
    }
    
}

function showResultSuccess(result){ // result is a JavaScript Object
	WL.Logger.debug("Connection was successful");
	busyIndicator.hide();
	
	if (result.invocationResult.result.length>0){
		var arr = JSON.parse(result.invocationResult.result);
		displayFeeds(arr.list);
	}else{
		alert("There is no information to display.");
	}
	
}

function showResultFailure(result){
	WL.Logger.error("showResultFailure");
	busyIndicator.hide();

	WL.SimpleDialog.show("Fail", "Service not available. Try again later.", 
			[{
				text : 'Reload',
				handler : WL.Client.reloadApp 
			},
			{
				text: 'Close',
				handler : function() {}
			}]
		);
}
