package com.ibm.zvse.adapter;

import java.io.IOException;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.Vector;

import javax.resource.ResourceException;

import com.ibm.vse.connector.VSEConnectionSpec;
//import com.ibm.vse.connector.VSEConsole;
import com.ibm.vse.connector.VSESystem;
import com.ibm.vse.connector.VSEVsam;
import com.ibm.vse.connector.VSEVsamCluster;
import com.ibm.vse.connector.VSEVsamMap;
import com.ibm.vse.connector.VSEVsamRecord;
import com.worklight.server.bundle.api.WorklightConfiguration;



/**
 * In order to use this sample you need to modify worklight.properties file:
 * 	Add the following lines:
 * 		zvse.host=your.zvse.host
 * 		zvse.port=port
 * 		zvse.username=user
 * 		zvse.psw=userPassword
 * 
 * Or change this file accordingly
 *  
 */

public class skvssampJava {

	static String catName = "VSESP.USER.CATALOG";
	static String fileName = "VSAM.CONN.SAMPLE.DATA";
	static String mapName = "USEDCARS";

    public static String getWorklightProperty(String propertyName){
        return WorklightConfiguration.getInstance().getString(propertyName); 
    }

    public static Vector<VSEVsamRecord> getAllRecords() {
		VSEConnectionSpec spec;
		Vector<VSEVsamRecord> vRecords = new Vector<VSEVsamRecord>();
		try {
			spec = new VSEConnectionSpec(
					InetAddress.getByName(getWorklightProperty("zvse.host")), 
					Integer.parseInt(getWorklightProperty("zvse.port")),
					getWorklightProperty("zvse.username"),  
					getWorklightProperty("zvse.psw"));

			/* Stay logon with this user for lifetime of this connection */
			spec.setLogonMode(true);
			/* Create VSE system instance with this connection */
			VSESystem system = new VSESystem(spec);
			/* Keep the connection for lifetime of this program */
			system.setConnectionMode(true);
			/* Get list of catalogs from host */
			VSEVsam vsam = system.getVSEVsam();

			/* Create a listener that gets notified when objects are */
			/* retrieved from the host */
			RecordListener rl = new RecordListener();
			vsam.addVSEResourceListener(rl);

			/* Get VSAM records from host using the given map */
			VSEVsamMap map = new VSEVsamMap(system, catName, fileName, mapName);
			map.refresh();

			VSEVsamCluster cluster = vsam.getVSEVsamCluster(catName, fileName);
			cluster.addVSEResourceListener(rl);
			cluster.selectRecords(map);
			cluster.removeVSEResourceListener(rl);

			/* Get vector containing all records from listener */
			vRecords = rl.getRecords();

		} catch (UnknownHostException e) {
			e.printStackTrace();
		} catch (ResourceException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}

		return vRecords;
	}

	private static String getInfo() {
		Vector<VSEVsamRecord> allRecords = getAllRecords();

		String result = "{\"list\":[";
		for (int i = 0; i < allRecords.size(); i++) {

			if (i != 0)
				result += ",";
			try {
				VSEVsamRecord rec = allRecords.get(i);
				String objResult = "{";
				// ARTICLENO MANUFACTURER TYPE MODEL HP DISPLACEMENT CYLINDERS
				// COLOUR FEATURES PRICE
				objResult += "\"ARTICLENO\":\"" + rec.getField(0) + "\",";
				objResult += "\"MANUFACTURER\":\"" + rec.getField(1) + "\",";
				objResult += "\"TYPE\":\"" + rec.getField(2) + "\",";
				objResult += "\"MODEL\":\"" + rec.getField(3) + "\",";
				objResult += "\"HP\":\"" + rec.getField(4) + "\",";
				objResult += "\"DISPLACEMENT\":\"" + rec.getField(5) + "\",";
				objResult += "\"CYLINDERS\":\"" + rec.getField(6) + "\",";
				objResult += "\"COLOUR\":\"" + rec.getField(7) + "\",";
				objResult += "\"FEATURES\":\"" + rec.getField(8) + "\",";
				objResult += "\"PRICE\":\"" + rec.getField(9) + "\"";
				objResult += "}";
				result += objResult;
			} catch (ResourceException e) {
				e.printStackTrace();
			} catch (IOException e) {
				e.printStackTrace();
			}
		}

		result += "]}";

		return result;
	}

	public String addNewCar(String manufacture, String type, String model,
			String hp, String displacement, String cylinders, String colour,
			String features, String price) {

		VSEConnectionSpec spec;
		try {
			spec = new VSEConnectionSpec(InetAddress.getByName(getWorklightProperty("zvse.host")), 
					Integer.parseInt(getWorklightProperty("zvse.port")),
					getWorklightProperty("zvse.username"),  getWorklightProperty("zvse.psw"));

			/* Stay logon with this user for lifetime of this connection */
			spec.setLogonMode(true);
			/* Create VSE system instance with this connection */
			VSESystem system = new VSESystem(spec);
			/* Keep the connection for lifetime of this program */
			system.setConnectionMode(true);
			/* Get list of catalogs from host */
			VSEVsam vsam = system.getVSEVsam();

			/* Create a listener that gets notified when objects are */
			/* retrieved from the host */
			RecordListener rl = new RecordListener();
			vsam.addVSEResourceListener(rl);

			/* Get VSAM records from host using the given map */
			VSEVsamMap map = new VSEVsamMap(system, catName, fileName, mapName);
			map.refresh();

			VSEVsamCluster cluster = vsam.getVSEVsamCluster(catName, fileName);
			VSEVsamRecord lastRecord = cluster.getLastRecord(mapName);
			int numRec = (Integer) lastRecord.getField(0);

			VSEVsamRecord newRecord = new VSEVsamRecord(system, catName,
					fileName, mapName);
			newRecord.setKeyField(0, new Integer(numRec + 1));
			newRecord.setField(1, makeString(manufacture, 20));
			newRecord.setField(2, makeString(type, 20));
			newRecord.setField(3, makeString(model, 20));
			newRecord.setField(4, new Short(hp));
			newRecord.setField(5, new Short(displacement));
			newRecord.setField(6, new Short(cylinders));
			newRecord.setField(7, makeString(colour, 20));
			newRecord.setField(8, makeString(features, 20));
			newRecord.setField(9, new Integer(price));

			newRecord.add();

		} catch (UnknownHostException e) {
			e.printStackTrace();
		} catch (ResourceException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}

		return getInfo();
	}

	public String changeCar(int k, String manufacture, String type,
			String model, String hp, String displacement, String cylinders,
			String colour, String features, String price) {

		VSEConnectionSpec spec;
		Vector<VSEVsamRecord> vRecords = getAllRecords();
		try {
			spec = new VSEConnectionSpec(InetAddress.getByName(getWorklightProperty("zvse.host")), 
					Integer.parseInt(getWorklightProperty("zvse.port")),
					getWorklightProperty("zvse.username"),  getWorklightProperty("zvse.psw"));

			/* Stay logon with this user for lifetime of this connection */
			spec.setLogonMode(true);
			/* Create VSE system instance with this connection */
			VSESystem system = new VSESystem(spec);
			/* Keep the connection for lifetime of this program */
			system.setConnectionMode(true);
			/* Get list of catalogs from host */
			VSEVsam vsam = system.getVSEVsam();

			/* Create a listener that gets notified when objects are */
			/* retrieved from the host */
			RecordListener rl = new RecordListener();
			vsam.addVSEResourceListener(rl);

			/* Get VSAM records from host using the given map */
			VSEVsamMap map = new VSEVsamMap(system, catName, fileName, mapName);
			map.refresh();

			VSEVsamRecord recToChange = vRecords.get(k);

			recToChange.setField(1, makeString(manufacture, 20));
			recToChange.setField(2, makeString(type, 20));
			recToChange.setField(3, makeString(model, 20));
			recToChange.setField(4, new Short(hp));
			recToChange.setField(5, new Short(displacement));
			recToChange.setField(6, new Short(cylinders));
			recToChange.setField(7, makeString(colour, 20));
			recToChange.setField(8, makeString(features, 20));
			recToChange.setField(9, new Integer(price));

			recToChange.commit();

		} catch (UnknownHostException e) {
			e.printStackTrace();
		} catch (ResourceException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}

		return getInfo();
	}

	public String deleteCar(int k) {

		VSEConnectionSpec spec;
		Vector<VSEVsamRecord> vRecords = getAllRecords();
		try {
			spec = new VSEConnectionSpec(InetAddress.getByName(getWorklightProperty("zvse.host")), 
					Integer.parseInt(getWorklightProperty("zvse.port")),
					getWorklightProperty("zvse.username"),  getWorklightProperty("zvse.psw"));

			/* Stay logon with this user for lifetime of this connection */
			spec.setLogonMode(true);
			/* Create VSE system instance with this connection */
			VSESystem system = new VSESystem(spec);
			/* Keep the connection for lifetime of this program */
			system.setConnectionMode(true);
			/* Get list of catalogs from host */
			VSEVsam vsam = system.getVSEVsam();

			/* Create a listener that gets notified when objects are */
			/* retrieved from the host */
			RecordListener rl = new RecordListener();
			vsam.addVSEResourceListener(rl);

			/* Get VSAM records from host using the given map */
			VSEVsamMap map = new VSEVsamMap(system, catName, fileName, mapName);
			map.refresh();

			VSEVsamRecord recToChange = vRecords.get(k);
			recToChange.delete(true);

		} catch (UnknownHostException e) {
			e.printStackTrace();
		} catch (ResourceException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}

		return getInfo();
	}

	/**
	 * This method padds or cuts a String to a given length
	 */
	public static String makeString(String s, int len) {
		int i;

		// append blanks to have at least len chats in the string
		for (i = s.length(); i < len; i++)
			s = s + " ";

		// cut the string if it is too long
		if (s.length() > len)
			s = s.substring(0, len);

		return (s);
	}
}
